using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using System.Web.Mvc.Ajax;
using Kona.Model;
using Kona.Infrastructure;

namespace Kona.Web.App.Controllers
{

    //TODO - make sure we only accept ValidTokens!
    public class CartController : KonaController
    {
        IProductRepository _productRepository;
        ICustomerRepository _customerRepository;
        IObjectStore _objectStore;

        public CartController(ICustomerRepository customerRepository,
            IObjectStore objectStore,
            IProductRepository productRepository) : base(customerRepository,objectStore) {
            _productRepository = productRepository;
            _objectStore = objectStore;
            _customerRepository = customerRepository;
        }

        public ActionResult Index()
        {
            return View();
        }

        #region Cart Actions

        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult AddItem(string sku) {

            Product p=_productRepository.GetProduct(sku);
            if(p==null)
                throw new InvalidOperationException("Invalid SKU");
            this.CurrentCart.AddItem(p);
            this.SaveCart();
            return RedirectToAction("Show");
        }
        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult RemoveItem(string id) {

            this.CurrentCart.RemoveItem(id);
            this.SaveCart();
            return RedirectToAction("Show");
        }
        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult UpdateItem(string id) {
            string sQuantity = Request.Form["quantity"];
            
            if (!string.IsNullOrEmpty(sQuantity)) {
                int newQuantity = 0;
                int.TryParse(sQuantity, out newQuantity);
                if (newQuantity > 0) {

                    this.CurrentCart.AdjustQuantity(id, newQuantity);
                    this.SaveCart();
                }
            }
            return RedirectToAction("Show");
        }
        public ActionResult Show() {
            //all the cart info is pulled by the base class
            return View("Cart");
        }

        #endregion
    
    
    
    
    }
}
