using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using System.Web.Mvc.Ajax;
using Kona.Model;
using Kona.Infrastructure;

namespace Kona.Web.App.Controllers
{
    public class OrderController : KonaController
    {
        IOrderRepository _orderRepository;
        ICustomerRepository _customerRepository;
        IObjectStore _objectStore;

        public OrderController(ICustomerRepository customerRepository, 
            IOrderRepository orderRepository,
            IObjectStore objectStore) : base(customerRepository,objectStore) {
            
            _objectStore = objectStore;
            _orderRepository = orderRepository;
            _customerRepository = customerRepository;
        }

        public ActionResult Index()
        {
            return View();
        }

        #region PayPal Display
        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult PayPal(int id) {
            //a shipping method was submitted
            //evaluate it
            if (id > 0) {
                //pull the shipping methods
                this.ShippingMethods = this.GetShippingMethods(this.CurrentCart);
                var selectedShipping = this.ShippingMethods.SingleOrDefault(x => x.ID == id);
                this.CurrentCart.ShippingService = selectedShipping.ServiceName;
                this.CurrentCart.ShippingAmount = selectedShipping.Cost;
                this.CurrentCart.ShippingMethodID = selectedShipping.ID;

            }
            return View("PayPal");
        }

        [AcceptVerbs(HttpVerbs.Get)]
        public ActionResult PayPal() {

            //they've selected PayPal
            //so we need to defaul the shipping selection for them
            //make sure they can checkout
            if (this.CurrentCart.Items.Count <= 0) {
                //TODO - localize this and check to see if the order requires shipping
                ViewData["ErrorMessage"] = "You need to have at least one item in your cart and selected a shipping address in order to checkout";
                return View("Billing");
            } else {

                this.ShippingMethods = this.GetShippingMethods(this.CurrentCart);
                this.CurrentCart.ShippingService = this.ShippingMethods[0].ServiceName;
                this.CurrentCart.ShippingAmount = this.ShippingMethods[0].Cost;
                this.CurrentCart.ShippingMethodID = this.ShippingMethods[0].ID;

            }
            return View("PayPal");
        }
        #endregion


        public ActionResult Checkout() {
            //they need to have items in their cart
            if (this.CurrentCart.Items.Count == 0)
                return RedirectToAction("Show","Cart");
            else if (User.Identity.IsAuthenticated)
                return RedirectToAction("Shipping");
            else
                return View("Checkout");

        }


        [AcceptVerbs(HttpVerbs.Get)]
        public ActionResult Shipping(int? id) {

            id = id ?? 0;
            if (id > 0) {
                this.CurrentCustomer.DefaultAddress = this.CurrentCustomer.AddressBook.Where(x => x.AddressID == (int)id).SingleOrDefault();
            }
            return View("Shipping");

        }

        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult Shipping(Address address) {
            //the address should be passed in
            if (ModelState.IsValid) {

                //save the address
                address.AddressID = _customerRepository.SaveAddress(address);
                this.CurrentCart.ShippingAddress = address; 

                //calc the tax
                this.CurrentCart.TaxAmount = this.CalculateTax(this.CurrentCart);
                
                
                //save the cart
                this.SaveCart();

                //send to billing
                return RedirectToAction("Billing");
            } else {
                //let error handling pick it up
                return View();
            }
        }

        [AcceptVerbs(HttpVerbs.Get)]
        public ActionResult Billing() {

            return View();

        }

        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult Billing(Address address) {

            if (ModelState.IsValid) {

                //save the address
                address.AddressID = _customerRepository.SaveAddress(address);
                
                this.CurrentCart.BillingAddress = address;

                //set the shipping methods
                this.ShippingMethods = this.GetShippingMethods(this.CurrentCart);
                
                //default to the first
                this.CurrentCart.ShippingService = this.ShippingMethods[0].ServiceName;
                this.CurrentCart.ShippingAmount = this.ShippingMethods[0].Cost;
                this.CurrentCart.ShippingMethodID = this.ShippingMethods[0].ID;
                //save the cart
                this.SaveCart();

                //send them to Finalize
                return RedirectToAction("Finalize");
            } else {
                return View();
            }

        }        
        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult Payment(CreditCard card) {
            //set the card
            this.CurrentCart.CreditCard = card;
            
            //create an order
            Order order = new Order(this.CurrentCustomer, DateTime.Now.Ticks.ToString());
            this.TempData["CurrentOrder"] = order;

            //TODO: - check boolean
            this.ValidateOrder(order);

            //execute the payment..
            Transaction trans = this.AuthorizeCreditCard(order);
            
            
            //on success send to Receipt
            if (trans.TransactionErrors.Count == 0) {

                //save it down
                //_orderRepository.Save(order, trans);
                
                this.CurrentCart.ClearItems();

                return RedirectToAction("Receipt", new { id = order.ID.ToString() });

            } else {

                ViewData["ErrorMessage"] = trans.TransactionErrors[0];

                //let the View know
                return View("Finalize");

            }

        }

        [AcceptVerbs(HttpVerbs.Get)]
        public ActionResult Finalize() {
            this.ShippingMethods = this.GetShippingMethods(this.CurrentCart);

            this.CurrentCart.ShippingService = this.ShippingMethods[0].ServiceName;
            this.CurrentCart.ShippingAmount = this.ShippingMethods[0].Cost;
            this.CurrentCart.ShippingMethodID = this.ShippingMethods[0].ID;
            return View();
        }

        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult Finalize(int? id) {
            if (id > 0) {
                this.ShippingMethods = this.GetShippingMethods(this.CurrentCart);
                var selectedShipping = this.ShippingMethods.SingleOrDefault(x => x.ID == id);
                this.CurrentCart.ShippingService = selectedShipping.ServiceName;
                this.CurrentCart.ShippingMethodID = selectedShipping.ID;
                this.CurrentCart.ShippingAmount = selectedShipping.Cost;
            }
            return View();
        }
        
        public ActionResult Receipt() {
            return View();
        }
    }
}
